@@ -206,6 +206,7 @@ void MainWindow::readSettings()
     int icons = sett.value("icons").toInt();
     int snap = sett.value("snap").toInt();
     int fontsize = themesett.value("fontsize").toInt();
+    QString fontsizestring = themesett.value("fontsize").toString();
 //    int iconset = sett.value("iconset").toInt();
     int appsize = sett.value("appsize").toInt();
     int booksize = sett.value("booksize").toInt();
@@ -225,8 +226,9 @@ void MainWindow::readSettings()
         ui->Icons->setCheckState(Qt::Unchecked);
     }
 
+    if ( !fontsizestring.isEmpty() ) {
     ui->FontSize->setCurrentIndex(fontsize);
-//    ui->Iconset->setCurrentIndex(iconset);
+    }
 
     if ( appsize > 15 ) {
     ui->lineEdit->setText(appsizestring);
@@ -246,12 +248,18 @@ void MainWindow::readSettings()
     if ( !opacitystring.isEmpty() ) {
     ui->Opacity->setText(opacitystring);
     ui->horizontalSlider_4->setValue(opacity);
+    } else {
+    ui->Opacity->setText("255");
+    ui->horizontalSlider_4->setValue(255);
     }
 
     if ( !opacitystring_top.isEmpty() ) {
     ui->Opacity_top->setText(opacitystring_top);
     ui->horizontalSlider_5->setValue(opacity_top);
-    }
+} else {
+    ui->Opacity_top->setText("255");
+    ui->horizontalSlider_5->setValue(255);
+}
 
 }
 
@@ -358,6 +366,7 @@ void MainWindow::runscript(QString command)
                 muoks0->start("/sbin/launchcustomizer", systemcommand);
                 muoks0->waitForFinished();
                 progress.setValue(5);
+                saveasnew = "0";
 
     }
 
@@ -371,14 +380,15 @@ void MainWindow::runscript(QString command)
         progress.setValue(35);
         oldfonts("/etc/hildon/theme/colors.config");
         progress.setValue(40);
+        readgtkrc();
         progress.setValue(45);
         progress.setValue(50);
         readSettings();
         progress.setValue(55);
         progress.setValue(60);
         progress.setValue(70);
-        readgtkrc();
         progress.setValue(80);
+        writeSettings();
         progress.setValue(90);
         progress.cancel();
         QMaemo5InformationBox::information(this, tr("New theme saved!"), QMaemo5InformationBox::DefaultTimeout);
@@ -771,7 +781,7 @@ void MainWindow::on_about_triggered()
     msgBox.setWindowTitle(tr("About Theme Customizer"));
     msgBox.setText("Author: d-iivil - Licence: Freeware & open source (GPL)");
     msgBox.setTextFormat(Qt::RichText);
-    msgBox.setInformativeText("<html>Version: 0.9-43<br /><a href=\"https://www.paypal.com/cgi-bin/webscr?cmd=_donations&business=ricky%40hevikaraoke%2efi&lc=FI&item_name=Here%27s%20some%20money%20for%20beer%2e&no_note=0&currency_code=EUR&bn=PP%2dDonationsBF%3abtn_donate_SM%2egif%3aNonHostedGuest\">Be a nice guy and <b>donate some money for beer</b> to author</a></html>");
+    msgBox.setInformativeText("<html>Version: 0.9-44<br /><a href=\"https://www.paypal.com/cgi-bin/webscr?cmd=_donations&business=ricky%40hevikaraoke%2efi&lc=FI&item_name=Here%27s%20some%20money%20for%20beer%2e&no_note=0&currency_code=EUR&bn=PP%2dDonationsBF%3abtn_donate_SM%2egif%3aNonHostedGuest\">Be a nice guy and <b>donate some money for beer</b> to author</a></html>");
     msgBox.setStandardButtons(QMessageBox::Ok);
     msgBox.setDefaultButton(QMessageBox::Ok);
     msgBox.button(msgBox.Ok)->setText(tr("Ok, thanks."));
